@@ -9,7 +9,7 @@ from tox_ini_fmt.formatter import format_tox_ini
 
 def run(args: Optional[Sequence[str]] = None) -> int:
     opts = cli_args(sys.argv[1:] if args is None else args)
-    formatted = format_tox_ini(opts.tox_ini)
+    formatted = format_tox_ini(opts.tox_ini, opts)
     before = opts.tox_ini.read_text()
     changed = before != formatted
     if opts.stdout:  # stdout just prints new format to stdout
