@@ -1,7 +1,7 @@
 import re
 from typing import List
 
-BASE_NAME_REGEX = re.compile(r"[^!=><\s@]+")
+BASE_NAME_REGEX = re.compile(r"[^!=><~\s@]+")
 REQ_REGEX = re.compile(r"(===|==|!=|~=|>=?|<=?|@)\s*([^,]+)")
 
 
@@ -9,7 +9,7 @@ def requires(raw: str) -> List[str]:
     require_group = raw.strip().splitlines()
     if not require_group:
         return []
-    values = (_normalize_req(req) for req in require_group)
+    values = (_normalize_req(req) for req in require_group if req)
     normalized = sorted(values, key=lambda req: (";" in req, _req_base(req), req))
     return normalized
 
@@ -30,7 +30,7 @@ def _normalize_lib(lib: str) -> str:
         key=lambda c: ("<" in c, ">" in "c", c),
     )
     if values:  # strip .0 version
-        while values[0].endswith(".0"):
+        while values[0].endswith(".0") and (values[0].startswith(">=") or values[0].startswith("==")):
             values[0] = values[0][:-2]
     return f"{base}{','.join(values)}"
 
@@ -38,5 +38,5 @@ def _normalize_lib(lib: str) -> str:
 def _req_base(lib: str) -> str:
     match = re.match(BASE_NAME_REGEX, lib)
     if match is None:
-        raise ValueError(lib)
+        raise ValueError(repr(lib))
     return match.group(0)
